const winston = require('winston');
const maillog = {
    transports: [
        new winston.transports.File({filename: 'mail.log', level: 'info'}),
    ],
};
const submitlog = {
    transports: [
        new winston.transports.File({filename: 'submissions.log', level: 'info'}),
    ],
};
const httplog = {
    transports: [
        new winston.transports.File({filename: 'request.log', level: 'info'}),
    ],
};
module.exports = {
    schema: 2,
    port: 9998,
    theme: {
        timezone: 'Europe/Helsinki',
        title: 'Join Social.Coop',
        description: 'A Cooperative Corner of the Fediverse',
        logo: 'images/social_coop_logo.svg',
        urls: {
            // The site home URL - logo links to this
            home: 'https://join.social.coop',
            // The top level url of the site 
            base: 'https://join.social.coop',
            // An url to prepend author usernames to
            authorbase: 'https://git.coop/',
        },
    },    
    email: {
        server: {
            user: "postmaster@mg.social.coop",
            password: "CHANGEME",
            host: "smtp.mailgun.org",
            port: 25,
            timeout: 15000, // (Default tends to need to be increased)
            tls: true,
        },
        registration: {
            from: "Registrations <registrations@social.coop>", 
            to: "Registrations <registrations@social.coop>",
            notification: "Social.coop | Someone has registered!",
            acknowledgement: "Social.coop | Thanks for registering.",
        },
        templates: {
            notification: './src/templates/notification.hbs',
            acknowledgement: './src/templates/acknowledgement.hbs'
        },
    },
    gitlab: {
        server: {
            issuesUrl: 'https://git.coop/api/v4/projects/764/issues',
            token: 'CHANGEME',
        },
        registration: {
            description: './src/templates/issue.hbs',
        },
    },
    logging: {
            mail: maillog,
            submit: submitlog,
            http: httplog,
    },
    spamTraps: [
        { emptyfield: '' },
        (fields) => {
            const answer = fields['math-spam-trap'];
            return !/(nine)|(9)/i.test(answer)
        },
    ],
    oauth: {
        instance: "https://social.coop",
        clientId: "CHANGEME",
        clientSecret: "CHANGEME"
    },
    cookieSecret: "CHANGEME"
};
